@@ -3,16 +3,16 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 /*
@@ -23,18 +23,21 @@
  *      the log.
  *
  */
-#include <unistd.h>
-#include "config.h"
+#include <config.h>
 #include <fcntl.h>
+#include <stdio.h>
+#include <string.h>
+#include <unistd.h>
 
-/*
- * includes from JFS fsck
- */
+#include "devices.h"
+#include "diskmap.h"
 #include "fsckwsp.h"
 #include "fsck_message.h"
 #include "jfs_endian.h"
-
 #include "jfs_fscklog.h"
+#include "super.h"
+#include "utilsubs.h"
+#include "xfsck.h"
 
 #define fsck_READ  1
 #define fsck_WRITE 2
@@ -111,7 +114,7 @@ int validate_superblock(void);
  *
  * FUNCTION: Entry point for jfs read aggregate fsck service log
  *
- * PARAMETERS:  
+ * PARAMETERS:
  *           local_recptr - fscklog record
  *
  * RETURNS:
@@ -146,7 +149,7 @@ int xchklog(struct fscklog_record *local_recptr)
 /***************************************************************************
  * NAME: extract_service_log
  *
- * FUNCTION:  
+ * FUNCTION:
  *
  * PARAMETERS:  none
  *
@@ -206,13 +209,13 @@ void extract_service_log()
 					/* the log record length looks ok */
 					msg_txt = &log_entry[log_entry_pos];
 
-					/* 
+					/*
 					 * record the message in the output file
 					 */
 					record_msg(msg_txt);
-					
-					/* 
-					 * set up for the next record 
+
+					/*
+					 * set up for the next record
 					 */
 					local_recptr->infile_buf_data_len +=
 					    hdptr->entry_length;
@@ -238,7 +241,7 @@ void extract_service_log()
 /***************************************************************************
  * NAME: xchklog_final_processing
  *
- * FUNCTION:  If processing read/write, replicate the superblock and the 
+ * FUNCTION:  If processing read/write, replicate the superblock and the
  *            aggregate inode structures (i.e., the Aggregate Inode Map
  *            and the Aggregate Inode Table).
  *
@@ -291,10 +294,10 @@ int xchklog_final_processing()
  *
  * NOTES:  o Unlike most _put_ routines in this module, fscklog_put_buffer
  *           actually writes to the device.  This is done because the fsck
- *           log contains information which provides crucial serviceability 
+ *           log contains information which provides crucial serviceability
  *           should the fsck session be interrupted.
  *
- *         o Errors here are recorded in the control page of the fsck 
+ *         o Errors here are recorded in the control page of the fsck
  *           in-aggregate workspace but never affect other fsck processing.
  *
  * RETURNS:
@@ -318,7 +321,7 @@ int xchklog_fscklog_fill_buffer()
 	    || (bytes_read != (unsigned) local_recptr->infile_buf_length)) {
 		/*
 		 * write failed or didn't read
-		 * correct number of bytes 
+		 * correct number of bytes
 		 */
 		send_msg(fsck_URCVWRT, fsck_ref_msg(fsck_metadata), Vol_Label);
 
@@ -329,7 +332,7 @@ int xchklog_fscklog_fill_buffer()
 	}
 	/*
 	 * We want to reset the buffer no matter what.  If is useful
-	 * to keep going because the next section may be readable. 
+	 * to keep going because the next section may be readable.
 	 */
 	local_recptr->infile_agg_offset += local_recptr->infile_buf_length;
 	local_recptr->infile_log_offset += local_recptr->infile_buf_length;
@@ -347,13 +350,13 @@ int xchklog_fscklog_fill_buffer()
 /*****************************************************************************
  * NAME: xchklog_initial_processing
  *
- * FUNCTION: Parse and verify invocation parameters.  
- *           Open the device and verify that it contains a JFS file system.  
+ * FUNCTION: Parse and verify invocation parameters.
+ *           Open the device and verify that it contains a JFS file system.
  *           Read the chkdsk workspace control page.
  *           Calculate interesting aggregate offsets.
  *
  *
- * PARAMETERS:  as specified to main()     
+ * PARAMETERS:  as specified to main()
  *
  * NOTES:
  *
@@ -423,7 +426,7 @@ int xchklog_initial_processing(struct fscklog_record *local_recptr)
 			local_recptr->ondev_fscklog_byte_offset =
 			    local_recptr->ondev_wsp_byte_offset +
 			    local_recptr->ondev_wsp_byte_length;
-			/* 
+			/*
 			 * The offsets now assume the most recent log is 1st in the
 			 * aggregate fsck service log space.  Adjust if needed.
 			 */
@@ -558,7 +561,7 @@ int open_outfile()
 /*****************************************************************************
  * NAME: readwrite_device
  *
- * FUNCTION:  Read data from or write data to the device on which the 
+ * FUNCTION:  Read data from or write data to the device on which the
  *            aggregate resides.
  *
  * PARAMETERS:
@@ -622,7 +625,7 @@ int readwrite_device(int64_t dev_offset,
 /*****************************************************************************
  * NAME: record_msg
  *
- * FUNCTION: Record an fsck service log message in the output file, 
+ * FUNCTION: Record an fsck service log message in the output file,
  *           formatted for the common fsck service log display tool.
  *
  * PARAMETERS:
@@ -631,12 +634,12 @@ int readwrite_device(int64_t dev_offset,
  *
  * NOTES:  Any message designated fsck_debug is english-only, and
  *         is issued in english, even if it is sent to stdout.
- *        
- *         All other messages are local-language (in the nls context)
- *         and, when sent to stdout or stderr, are issued in the 
- *         local language.  
  *
- *         Regardless of the language used to send a message to 
+ *         All other messages are local-language (in the nls context)
+ *         and, when sent to stdout or stderr, are issued in the
+ *         local language.
+ *
+ *         Regardless of the language used to send a message to
  *         stdout and stderr, messages are ALWAYS LOGGED IN ENGLISH.
  *
  * RETURNS:
@@ -824,7 +827,7 @@ int validate_super(int which_super)
 
 		if (!vs_rc) {
 			/*
-			 * check out the fsck in-aggregate workspace 
+			 * check out the fsck in-aggregate workspace
 			 */
 			fsck_length_from_pxd = lengthPXD(&(sb_ptr->s_fsckpxd));
 			fsck_start_from_pxd = addressPXD(&(sb_ptr->s_fsckpxd));
@@ -846,7 +849,7 @@ int validate_super(int which_super)
 				    (fsck_blkmap_size_pages << L2PSIZE) /
 				    sb_ptr->s_bsize;
 				/*
-				 * aggregate block offset of the 
+				 * aggregate block offset of the
 				 * fsck workspace in the aggregate.
 				 */
 				fsck_blkmap_start_blks =
@@ -854,7 +857,7 @@ int validate_super(int which_super)
 				if (fsck_length_from_pxd !=
 				    fsck_blkmap_size_blks) {
 					/*
-					 * length of fsck in-aggregate 
+					 * length of fsck in-aggregate
 					 * workspace is incorrect
 					 */
 					vs_rc = FSCK_BADSBFWSL;
@@ -864,7 +867,7 @@ int validate_super(int which_super)
 				if (fsck_start_from_pxd !=
 				    fsck_blkmap_start_blks) {
 					/*
-					 * address of fsck in-aggregate 
+					 * address of fsck in-aggregate
 					 * workspace is incorrect
 					 */
 					vs_rc = FSCK_BADSBFWSA;
@@ -910,7 +913,7 @@ int validate_super(int which_super)
 /*****************************************************************************
  * NAME: validate_superblock
  *
- * FUNCTION:  Verify that the primary superblock is valid.  
+ * FUNCTION:  Verify that the primary superblock is valid.
  *            If not, verify that the secondary superblock is valid.
  *
  * PARAMETERS:  none
