@@ -24,6 +24,9 @@
 #include <stdlib.h>
 
 #ifdef HAVE_SYS_MOUNT_H
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
 #include <sys/mount.h>
 #endif
 
@@ -33,6 +36,9 @@
 #if defined(__DragonFly__)
 #include <machine/param.h>
 #include <sys/diskslice.h>
+#endif
+
+#ifdef HAVE_SYS_DISKLABEL_H
 #include <sys/disklabel.h>
 #endif
 
@@ -194,6 +200,28 @@ int ujfs_get_dev_size(FILE *device, int64_t *size)
 		return 0;
 	}
 #endif
+#if defined(HAVE_SYS_DISKLABEL_H) && !defined(__DragonFly__)
+	{
+		struct disklabel dl;
+		struct partition * part;
+		dev_t dev = stat_data.st_rdev;
+
+		rc = ioctl(devfd, DIOCGDINFO, &dl);
+		if (rc < 0)
+			return -1;
+		part = dl.d_partitions + DISKPART(dev);
+
+		*size = (dl.d_secsize * part->p_size);
+
+		DBG_TRACE(("ujfs_get_device_size: size in bytes = %ld\n", 
+			*size));
+		DBG_TRACE(("ujfs_get_device_size: size in megabytes = %ld\n",
+			*size / (1024 * 1024)));
+
+		return NO_ERROR;
+	}
+#endif
+
 
 	/*
 	 * If the ioctl above fails or is undefined, use a binary search to
