@@ -251,6 +251,13 @@ void ujfs_swap_dtpage_t(dtpage_t * dtp_t, uint32_t sb_flag)
 		stbl = (int8_t *) & dtp_t->slot[dtp_t->header.stblindex];
 		lastslot = DTPAGEMAXSLOT - 1;
 	}
+	/*
+	 * Make sure we don't dereference beyond the end of stbl.
+	 * We can keep quiet here.  The problem will be reported elsewhere.
+	 */
+	if (dtp_t->header.nextindex > lastslot + 1)
+		return;
+
 	if (dtp_t->header.flag & BT_LEAF) {
 		struct ldtentry *ldtentry;
 
@@ -265,16 +272,17 @@ void ujfs_swap_dtpage_t(dtpage_t * dtp_t, uint32_t sb_flag)
 			ldtentry = (struct ldtentry *) &dtp_t->slot[index];
 			ldtentry->inumber = __le32_to_cpu(ldtentry->inumber);
 
-			if ((sb_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX)
+			if ((sb_flag & JFS_DIR_INDEX) == JFS_DIR_INDEX) {
 				DtlHdrDataLen = DTLHDRDATALEN;
-			else
+				ldtentry->index =
+					__le32_to_cpu(ldtentry->index);
+			} else
 				DtlHdrDataLen = DTLHDRDATALEN_LEGACY;
 
 			len = ldtentry->namlen;
 			for (j = 0; j < MIN(ldtentry->namlen, DtlHdrDataLen); j++)
 				ldtentry->name[j] = __le16_to_cpu(ldtentry->name[j]);
 			len -= DtlHdrDataLen;
-			ldtentry->index = __le32_to_cpu(ldtentry->index);
 
 			index = ldtentry->next;
 			/*
