@@ -3,19 +3,19 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "jfs_types.h"
+#include <config.h>
 #include <time.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -23,6 +23,7 @@
 #include <string.h>
 #include <fcntl.h>
 #include <errno.h>
+#include "jfs_types.h"
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
@@ -645,8 +646,6 @@ void ldmp_xdump(char *saddr, int count)
 	char *linestart;
 	int asciistart;
 	char asterisk = ' ';
-	void ldmp_x_scpy();
-	int ldmp_x_scmp();
 
 	hexchar = "0123456789ABCDEF";
 	prevbuf[0] = '\0';
