@@ -3,22 +3,22 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 /*
  *   FUNCTION: log_map.c: recovery manager
  */
-#include "jfs_types.h"
+#include <config.h>
 #include <assert.h>
 #include <time.h>
 #include <stdio.h>
@@ -26,6 +26,7 @@
 #include <memory.h>
 #include <string.h>
 #include <errno.h>
+#include "jfs_types.h"
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
@@ -38,7 +39,6 @@
 #include "logredo.h"
 #include "devices.h"
 #include "debug.h"
-
 #include "fsck_message.h"		/* for fsck message logging facility */
 
  /* + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +
@@ -511,7 +511,7 @@ int bMapInit(int vol,		/* index in vopen array */
  * FUNCTION:	Read the requested block map page from the device
  *                   into the specified buffer.
  *
- * NOTES:	
+ * NOTES:
  *
  */
 int bMapRead(int vol,		/* index in vopen array */
@@ -540,7 +540,7 @@ int bMapRead(int vol,		/* index in vopen array */
  * FUNCTION:	Write the contents of the given buffer to the specified
  *                   block map page on the device
  *
- * NOTES:	
+ * NOTES:
  *
  */
 int bMapWrite(int vol,		/* index in vopen array */
@@ -802,7 +802,7 @@ int iMapInit(int vol,		/* index in vopen array */
  * FUNCTION:	Read the requested inode map page from the device
  *                   into the specified buffer.
  *
- * NOTES:	
+ * NOTES:
  *
  */
 int iMapRead(int vol,		/* index in vopen array */
@@ -815,7 +815,7 @@ int iMapRead(int vol,		/* index in vopen array */
 	 * read in the map page
 	 */
 	imr_rc = ujfs_rw_diskblocks(vopen[vol].fp,
-				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset, 
+				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset,
 				    PSIZE, page_buffer, GET);
 	if (imr_rc != 0) {
 		fsck_send_msg(lrdo_RIMPREADDATFAIL);
@@ -831,7 +831,7 @@ int iMapRead(int vol,		/* index in vopen array */
  * FUNCTION:	Write the contents of the given buffer to the specified
  *                   inode map page on the device
  *
- * NOTES:	
+ * NOTES:
  *
  */
 int iMapWrite(int vol,		/* index in vopen array */
@@ -844,7 +844,7 @@ int iMapWrite(int vol,		/* index in vopen array */
 	 * write out the map page
 	 */
 	imw_rc = ujfs_rw_diskblocks(vopen[vol].fp,
-				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset, 
+				    vopen[vol].fsimap_lst.imap_wsp[page_number].page_offset,
 				    PSIZE, page_buffer, PUT);
 	if (imw_rc != 0) {
 		fsck_send_msg(lrdo_WRIMPBLKWRITEFAIL,
@@ -863,7 +863,7 @@ int iMapWrite(int vol,		/* index in vopen array */
  *                   the page read into the data and then initialize the wmap
  *                   in the data record.
  *
- * NOTES:	
+ * NOTES:
  *
  */
 int iagGet(int vol,		/* index in vopen array */
