@@ -3,26 +3,26 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "jfs_types.h"
-
+#include <config.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <stddef.h>
 #include <time.h>
 #include <errno.h>
+#include "jfs_types.h"
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_dinode.h"
@@ -185,7 +185,7 @@ int init_fileset_inode_table(int aggr_block_size,
 	 *
 	 * Release 1 will not support multiple filesets per aggregate, so the
 	 * location of the inode extent can be fixed.  However in future releases
-	 * this will have to be modified to find the space for this extent using 
+	 * this will have to be modified to find the space for this extent using
 	 * the block allocation map.
 	 */
 #ifdef ONE_FILESET_PER_AGGR
@@ -222,8 +222,8 @@ int init_fileset_inode_table(int aggr_block_size,
 	/*
 	 * Inode 1 - 2nd half of fileset superblock information
 	 *
-	 * When we add support for VFS this will be a special inode with 
-	 * different information.  For now we will just make it look like an 
+	 * When we add support for VFS this will be a special inode with
+	 * different information.  For now we will just make it look like an
 	 * empty inode to reserve it.
 	 */
 	memset(&inode_buffer, 0, sizeof (inode_buffer));
@@ -250,7 +250,7 @@ int init_fileset_inode_table(int aggr_block_size,
 
 	/*
 	 * Initialize the directory B+-tree header for the root inode
-	 * Since the root directory has no entries the nextindex is 0; nextindex 
+	 * Since the root directory has no entries the nextindex is 0; nextindex
 	 * is for the stbl index not the slot index.
 	 */
 	root_header = (dtroot_t *) & (inode_buffer.di_DASD);
@@ -340,7 +340,7 @@ int init_fileset_inodes(int aggr_block_size,
 			FILE *dev_ptr,
 			int64_t inode_map_loc,
 			int inode_map_size,
-			int64_t fileset_start, 
+			int64_t fileset_start,
 			unsigned inostamp)
 {
 	struct dinode inode_buffer;
@@ -350,9 +350,9 @@ int init_fileset_inodes(int aggr_block_size,
 	/*
 	 * Figure out which is the next free aggregate fileset inode
 	 *
-	 * Release 1 only supports one fileset per aggregate, so we know this 
-	 * will always be inode FILESYSTEM_I in the aggregate inode table.  In 
-	 * future releases we will need to modify this code to look in the 
+	 * Release 1 only supports one fileset per aggregate, so we know this
+	 * will always be inode FILESYSTEM_I in the aggregate inode table.  In
+	 * future releases we will need to modify this code to look in the
 	 * aggregate inode table for the next available free inode.
 	 */
 
@@ -416,8 +416,8 @@ void init_inode(struct dinode *new_inode,
 		int64_t first_block,
 		mode_t mode,
 		ino_data_type inode_type,
-		int64_t inoext_address, 
-		int aggr_block_size, 
+		int64_t inoext_address,
+		int aggr_block_size,
 		unsigned inostamp)
 {
 	/*
@@ -448,8 +448,8 @@ void init_inode(struct dinode *new_inode,
 		((xtpage_t *) & (new_inode->di_DASD))->header.flag =
 		    DXD_INDEX | BT_ROOT | BT_LEAF;
 		/*
-		 * Since this is the root, we don't actually use the next and 
-		 * prev entries.  Set to 0 in case we decide to use this space 
+		 * Since this is the root, we don't actually use the next and
+		 * prev entries.  Set to 0 in case we decide to use this space
 		 * for something in the future.
 		 */
 		((xtpage_t *) & (new_inode->di_DASD))->header.next = 0;
@@ -476,8 +476,8 @@ void init_inode(struct dinode *new_inode,
 		((xtpage_t *) & (new_inode->di_DASD))->header.flag =
 		    DXD_INDEX | BT_ROOT | BT_LEAF;
 		/*
-		 * Since this is the root, we don't actually use the next and 
-		 * prev entries.  Set to 0 in case we decide to use this space 
+		 * Since this is the root, we don't actually use the next and
+		 * prev entries.  Set to 0 in case we decide to use this space
 		 * for something in the future.
 		 */
 		((xtpage_t *) & (new_inode->di_DASD))->header.next = 0;
@@ -492,7 +492,7 @@ void init_inode(struct dinode *new_inode,
 		    0;
 		break;
 	default:
-		DBG_ERROR(("Internal error: %s(%d): Unrecognized inode data type %d\n", 
+		DBG_ERROR(("Internal error: %s(%d): Unrecognized inode data type %d\n",
 			  __FILE__, __LINE__, inode_type))
 		    break;
 	}
