@@ -19,7 +19,7 @@
 #include <fcntl.h>
 #include <unistd.h>
 #include <sys/stat.h>
-#if !defined(__DragonFly__)
+#if HAVE_SYS_SYSMACROS_H
 #include <sys/sysmacros.h>
 #endif
 #include <jfs_types.h>
@@ -1036,7 +1036,7 @@ format_journal:
 			rc = ENOSPC;
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
 			DBG_ERROR(("Internal error: Format failed rc=%x\n", rc))
-			    fclose(dev_handle);
+			fclose(dev_handle);
 			return (rc);
 		}
 
@@ -1049,7 +1049,7 @@ format_journal:
 		if (rc != 0) {
 			message_user(MSG_OSO_FORMAT_FAILED, NULL, 0, OSO_MSG);
 			DBG_ERROR(("Internal error: Format failed rc=%x\n", rc))
-			    fclose(dev_handle);
+			fclose(dev_handle);
 			return (rc);
 		}
 	}
