@@ -3,30 +3,30 @@
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or 
+ *   the Free Software Foundation; either version 2 of the License, or
  *   (at your option) any later version.
- * 
+ *
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software 
+ *   along with this program;  if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
+#include <config.h>
+#include <stdlib.h>
+#include <string.h>
+
 #include "xpeek.h"
-
-/* JFS includes */
-#include <jfs_filsys.h>
-#include <jfs_superblock.h>
-#include <jfs_logmgr.h>
-
-/* libfs includes */
-#include <fsckcbbl.h>
-#include <fsckwsp.h>
-#include <jfs_endian.h>
-#include <super.h>
+#include "jfs_filsys.h"
+#include "jfs_superblock.h"
+#include "jfs_logmgr.h"
+#include "fsckcbbl.h"
+#include "fsckwsp.h"
+#include "jfs_endian.h"
+#include "super.h"
 
 /* global data */
 extern int64_t fsckwsp_offset;	/* defined in xpeek.c    */
@@ -110,14 +110,14 @@ void logsuper()
 [2] cbbl_retcode: 	0		    [14] cbbl_agg_recptr:	0x00067f40
 [3] fs_blksize: 	1024		    [15] ImapInoPtr: 		0x00067cb0
 [4] lv_blksize:		512		    [16] ImapCtlPtr:		0x00061a70
-[5] fs_lv_ratio: 	2		
+[5] fs_lv_ratio: 	2
 [6] fs_last_metablk:	0x00000000000008a8    (0d02216)
 [7] fs_first_wspblk:	0x00000000001fba2b    (0d02079275)
-[8] total_bad_blocks:	20		
+[8] total_bad_blocks:	20
 [9] resolved_blocks:	18		    [17] ImapLeafPtr:		0x00060a60
 [10] reloc_extents:     14		    [18] iagPtr:		0x00066ca0
 [11] reloc_blocks:	1028		    [19] InoExtPtr:		0x00060a70
-[12] LVM_lists: 	3		
+[12] LVM_lists: 	3
 
  */
 int display_cbblfsck(struct fsck_blk_map_hdr *fsckwsp_ptr)
@@ -241,18 +241,18 @@ int display_cbblfsck(struct fsck_blk_map_hdr *fsckwsp_ptr)
  *
  *****************  Sample output of display_fsck_wsphdr()
 
-[1] eyecatcher:			'wspblkmp'	
-[2] last_entry_pos:		0		
-[3] next_entry_pos: 		0		
+[1] eyecatcher:			'wspblkmp'
+[2] last_entry_pos:		0
+[3] next_entry_pos: 		0
 [4] start_time: 		2/5/999.11.2
-[5] end_time:	 		2/5/999.11.4	
+[5] end_time:	 		2/5/999.11.4
 [6] return_code:		0
 [7] super_buff_addr:		0x164f0be0
-[8] agg_record_addr:		0x164f4cd0		
-[9] bmap_record_addr:		0x16463ce0		
+[8] agg_record_addr:		0x164f4cd0
+[9] bmap_record_addr:		0x16463ce0
 [10] fscklog_agg_offset:	0x000000003f786600	(0d01064855040)
 [11] fscklog_full:		0
-[12] fscklog_buf_allocated:	-1	
+[12] fscklog_buf_allocated:	-1
 [13] fscklog_buf_alloc_err:	0
 [14] num_logwrite_errors:	0
 
